==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/config/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 */
$lang['menu']                  = 'Parámetros de Configuración';
$lang['error']                 = 'Los parámetros no han sido actualizados a causa de un valor inválido, por favor revise los cambios y re-envíe el formulario. <br /> Los valores incorrectos se mostrarán con un marco rojo alrededor.';
$lang['updated']               = 'Los parámetros se actualizaron exitosamente.';
$lang['nochoice']              = '(no hay otras alternativas disponibles)';
$lang['locked']                = 'El archivo de configuración no ha podido ser actualizado, si esto no es lo deseado, <br /> asegúrese que el nombre del archivo local de configuraciones y los permisos sean los correctos.';
$lang['_configuration_manager'] = 'Administrador de configuración';
$lang['_header_dokuwiki']      = 'Parámetros de DokuWiki';
$lang['_header_plugin']        = 'Parámetros de Plugin';
$lang['_header_template']      = 'Parámetros de Plantillas';
$lang['_header_undefined']     = 'Parámetros sin categoría';
$lang['_basic']                = 'Parámetros Básicos';
$lang['_display']              = 'Parámetros de Presentación';
$lang['_authentication']       = 'Parámetros de Autenticación';
$lang['_anti_spam']            = 'Parámetros Anti-Spam';
$lang['_editing']              = 'Parámetros de Edición';
$lang['_links']                = 'Parámetros de Enlaces';
$lang['_media']                = 'Parámetros de Almacenamiento';
$lang['_advanced']             = 'Parámetros Avanzados';
$lang['_network']              = 'Parámetros de Red';
$lang['_plugin_sufix']         = 'Parámetros de Plugins';
$lang['_template_sufix']       = 'Parámetros de Plantillas';
$lang['_msg_setting_undefined'] = 'Sin parámetros de metadata.';
$lang['_msg_setting_no_class'] = 'No setting class.';
$lang['_msg_setting_no_default'] = 'No default value.';
$lang['fmode']                 = 'Modo de creación de ficheros';
$lang['dmode']                 = 'Modo de creación de directorios';
$lang['lang']                  = 'Idioma';
$lang['basedir']               = 'Directorio de Base';
$lang['baseurl']               = 'URL de Base';
$lang['savedir']               = 'Directorio para guardar los datos';
$lang['start']                 = 'Nombre de la página inicial';
$lang['title']                 = 'Título del Wiki';
$lang['template']              = 'Plantilla';
$lang['fullpath']              = 'Reveal full path of pages in the footer';
$lang['recent']                = 'Cambios recientes';
$lang['breadcrumbs']           = 'Número de pasos de traza';
$lang['youarehere']            = 'Traza jerárquica';
$lang['typography']            = 'Realizar reemplazos tipográficos';
$lang['htmlok']                = 'Permitir HTML embebido';
$lang['phpok']                 = 'Permitir PHP embebido';
$lang['dformat']               = 'Formato de fecha (ver la función de PHP <a href="http://www.php.net/strftime">strftime</a>)';
$lang['signature']             = 'Firma';
$lang['toptoclevel']           = 'Nivel superior para la tabla de contenidos';
$lang['maxtoclevel']           = 'Máximo nivel para la tabla de contenidos';
$lang['maxseclevel']           = 'Máximo nivel para edición de sección';
$lang['camelcase']             = 'Usar CamelCase para enlaces';
$lang['deaccent']              = 'Nombres de páginas "limpios"';
$lang['useheading']            = 'Usar el primer encabezado para nombres de páginas';
$lang['refcheck']              = 'Control de referencia a medios';
$lang['refshow']               = 'Número de referencias a medios a mostrar';
$lang['allowdebug']            = 'Permitir debug <b>deshabilítelo si no lo necesita!</b>';
$lang['usewordblock']          = 'Bloquear spam usando una lista de palabras';
$lang['indexdelay']            = 'Intervalo de tiempo antes de indexar (segundos)';
$lang['relnofollow']           = 'Usar rel="nofollow" en enlaces externos';
$lang['mailguard']             = 'Ofuscar direcciones de correo electrónico';
$lang['iexssprotect']          = 'Comprobar posible código malicioso (JavaScript ó HTML) en archivos subidos';
$lang['useacl']                = 'Usar listas de control de acceso (ACL)';
$lang['autopasswd']            = 'Autogenerar contraseñas';
$lang['authtype']              = 'Método de Autenticación';
$lang['passcrypt']             = 'Método de cifrado de contraseñas';
$lang['defaultgroup']          = 'Grupo por defecto';
$lang['superuser']             = 'Super-usuario - grupo ó usuario con acceso total a todas las páginas y funciones, configuraciones ACL';
$lang['manager']               = 'Manager - grupo ó usuario con acceso a ciertas tareas de mantenimiento.';
$lang['profileconfirm']        = 'Confirmar cambios en perfil con contraseña';
$lang['disableactions']        = 'Deshabilitar acciones DokuWiki';
$lang['disableactions_check']  = 'Controlar';
$lang['disableactions_subscription'] = 'Subscribirse/Desubscribirse';
$lang['disableactions_nssubscription'] = 'Directorio Subscribirse/Desubscribirse';
$lang['disableactions_wikicode'] = 'Ver el fuente/Exportar en formato crudo (raw)';
$lang['disableactions_other']  = 'Otras acciones (separadas por coma)';
$lang['sneaky_index']          = 'Por defecto, DokuWiki mostrará todos los namespaces en el index. Habilitando esta opción los ocultará si el usuario no tiene permisos de lectura. Los sub-namespaces pueden resultar inaccesibles. El index puede hacerse poco usable dependiendo de las configuraciones ACL.';
$lang['auth_security_timeout'] = 'Tiempo de Autenticación (en segundos), por motivos de seguridad';
$lang['updatecheck']           = 'Comprobar actualizaciones y advertencias de seguridad? Esta característica requiere que Dokuwiki se conecte a splitbrain.org.';
$lang['userewrite']            = 'Usar URLs bonitas';
$lang['useslash']              = 'Usar barra (/) como separador de espacios de nombres en las URLs';
$lang['usedraft']              = 'Guardar automáticamente un borrador mientras se edita';
$lang['sepchar']               = 'Separador de palabras en nombres de páginas';
$lang['canonical']             = 'Usar URLs totalmente canónicas';
$lang['autoplural']            = 'Controlar plurales en enlaces';
$lang['compression']           = 'Método de compresión para archivos en el ático';
$lang['cachetime']             = 'Edad máxima para caché (segundos)';
$lang['locktime']              = 'Edad máxima para archivos de lock (segundos)';
$lang['fetchsize']             = 'Tamañao máximo (bytes) que fetch.php puede descargar de sitios externos';
$lang['notify']                = 'Enviar notificación de cambios a esta dirección de correo electrónico';
$lang['registernotify']        = 'Enviar información cuando se registran nuevos usuarios a esta dirección de correo electrónico';
$lang['mailfrom']              = 'Dirección de correo electrónico para emails automáticos';
$lang['gzip_output']           = 'Usar gzip Content-Encoding para xhtml';
$lang['gdlib']                 = 'Versión de GD Lib';
$lang['im_convert']            = 'Ruta a la herramienta de conversión de ImageMagick';
$lang['jpg_quality']           = 'Calidad de compresión de JPG (0-100)';
$lang['subscribers']           = 'Habilitar soporte para subscripción a páginas';
$lang['compress']              = 'Compactar la salida de CSS y javascript';
$lang['hidepages']             = 'Ocultar páginas con coincidencias (expresiones regulares)';
$lang['send404']               = 'Enviar "HTTP 404/Page Not Found" para páginas no existentes';
$lang['sitemap']               = 'Generar sitemap de Google (días)';
$lang['broken_iua']            = '¿Se ha roto su sistema a causa de la función ignore_user_abort?. Esto puede causar que no funcione el index de búsqueda. Leer el <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>para más información.';
$lang['xsendfile']             = 'Utilice el X-Sendfile header para permitirle sl servidor web enviar archivos estáticos? Su servidor web necesita tener la capacidad para hacerlo.';
$lang['xmlrpc']                = 'Habilitar/Deshabilitar interfase XML-RPC';
$lang['renderer_xhtml']        = 'Visualizador a usar para salida (xhtml) principal del wiki';
$lang['renderer__core']        = '%s (nucleo dokuwiki)';
$lang['renderer__plugin']      = '%s (complemento)';
$lang['rss_type']              = 'Tipo de resumen (feed) XML';
$lang['rss_linkto']            = 'Feed XML enlaza a';
$lang['rss_content']           = 'Que mostrar en los itemes del archivo XML?';
$lang['rss_update']            = 'Intervalo de actualización de feed XML (segundos)';
$lang['recent_days']           = 'Cuántos cambios recientes mantener (días)';
$lang['rss_show_summary']      = 'Feed XML muestra el resúmen en el título';
$lang['target____wiki']        = 'Ventana para enlaces internos';
$lang['target____interwiki']   = 'Ventana para enlaces interwikis';
$lang['target____extern']      = 'Ventana para enlaces externos';
$lang['target____media']       = 'Ventana para enlaces a medios';
$lang['target____windows']     = 'Ventana para enlaces a ventanas';
$lang['proxy____host']         = 'Nombre del servidor Proxy';
$lang['proxy____port']         = 'Puerto del servidor Proxy';
$lang['proxy____user']         = 'Nombre de usuario para el servidor Proxy';
$lang['proxy____pass']         = 'Contraseña para el servidor Proxy';
$lang['proxy____ssl']          = 'Usar ssl para conectarse al servidor Proxy';
$lang['safemodehack']          = 'Habilitar edición (hack) de modo seguro';
$lang['ftp____host']           = 'Nombre del servidor FTP  para modo seguro';
$lang['ftp____port']           = 'Puerto del servidor FTP  para modo seguro';
$lang['ftp____user']           = 'Nombre de usuario para el servidor FTP  para modo seguro';
$lang['ftp____pass']           = 'Contraseña para el servidor FTP  para modo seguro';
$lang['ftp____root']           = 'Directorio raiz para el servidor FTP  para modo seguro';
$lang['typography_o_0']        = 'ninguno';
$lang['typography_o_1']        = 'Dobles comillas solamente';
$lang['typography_o_2']        = 'Todas las comillas (puede ser que no siempre funcione)';
$lang['userewrite_o_0']        = 'ninguno';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'Interno de DokuWiki';
$lang['deaccent_o_0']          = 'Apagado';
$lang['deaccent_o_1']          = 'Eliminar tildes';
$lang['deaccent_o_2']          = 'Romanizar';
$lang['gdlib_o_0']             = 'GD Lib no está disponible';
$lang['gdlib_o_1']             = 'Versión 1.x';
$lang['gdlib_o_2']             = 'Autodetección';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Resumen';
$lang['rss_content_o_diff']    = 'Diferencias unificadas';
$lang['rss_content_o_htmldiff'] = 'Tabla de diferencias en formato HTML';
$lang['rss_content_o_html']    = 'Página que contiente totalmente código HTML';
$lang['rss_linkto_o_diff']     = 'ver las diferencias';
$lang['rss_linkto_o_page']     = 'la página revisada';
$lang['rss_linkto_o_rev']      = 'lista de revisiones';
$lang['rss_linkto_o_current']  = 'la página actual';
$lang['compression_o_0']       = 'Ninguna';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'No utiliazar';
$lang['xsendfile_o_1']         = 'Encabezado propietario de lighttpd (antes de la version 1.5)';
$lang['xsendfile_o_2']         = 'Encabezado X-Sendfile estandar';
$lang['xsendfile_o_3']         = 'Encabezado propietario Nginx X-Accel-Redirect';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 */
$lang['menu']                  = 'Parámetros de Configuración';
$lang['error']                 = 'Los parámetros no han sido actualizados a causa de un valor inválido, por favor revise los cambios y re-envíe el formulario. <br /> Los valores incorrectos se mostrarán con un marco rojo alrededor.';
$lang['updated']               = 'Los parámetros se actualizaron con exito.';
$lang['nochoice']              = '(no hay otras alternativas disponibles)';
$lang['locked']                = 'El archivo de configuración no ha podido ser actualizado, si esto no es lo deseado, <br /> asegúrese que el nombre del archivo local de configuraciones y los permisos sean los correctos.';
$lang['_configuration_manager'] = 'Administrador de configuración';
$lang['_header_dokuwiki']      = 'Parámetros de DokuWiki';
$lang['_header_plugin']        = 'Parámetros de Plugin';
$lang['_header_template']      = 'Parámetros de Plantillas';
$lang['_header_undefined']     = 'Parámetros sin categoría';
$lang['_basic']                = 'Parámetros Básicos';
$lang['_display']              = 'Parámetros de Presentación';
$lang['_authentication']       = 'Parámetros de Autenticación';
$lang['_anti_spam']            = 'Parámetros Anti-Spam';
$lang['_editing']              = 'Parámetros de Edición';
$lang['_links']                = 'Parámetros de Enlaces';
$lang['_media']                = 'Parámetros de Almacenamiento';
$lang['_advanced']             = 'Parámetros Avanzados';
$lang['_network']              = 'Parámetros de Red';
$lang['_plugin_sufix']         = 'Parámetros de Plugins';
$lang['_template_sufix']       = 'Parámetros de Plantillas';
$lang['_msg_setting_undefined'] = 'Sin parámetros de metadata.';
$lang['_msg_setting_no_class'] = 'Sin Clase (class) establecida.';
$lang['_msg_setting_no_default'] = 'Sin valor por defecto.';
$lang['fmode']                 = 'Modo de creación de ficheros';
$lang['dmode']                 = 'Modo de creación de directorios';
$lang['lang']                  = 'Idioma';
$lang['basedir']               = 'Directorio de Base';
$lang['baseurl']               = 'URL de Base';
$lang['savedir']               = 'Directorio para guardar los datos';
$lang['start']                 = 'Nombre de la página inicial';
$lang['title']                 = 'Título del Wiki';
$lang['template']              = 'Plantilla';
$lang['license']               = '¿Bajo qué licencia será liberado tu contenido?';
$lang['fullpath']              = 'Camino (path) completo en el pié de página';
$lang['recent']                = 'Cambios recientes';
$lang['breadcrumbs']           = 'Número de pasos de traza';
$lang['youarehere']            = 'Traza jerárquica';
$lang['typography']            = 'Realizar reemplazos tipográficos';
$lang['htmlok']                = 'Permitir HTML embebido';
$lang['phpok']                 = 'Permitir PHP embebido';
$lang['dformat']               = 'Formato de fecha (ver la función de PHP <a href="http://www.php.net/strftime">strftime</a>)';
$lang['signature']             = 'Firma';
$lang['toptoclevel']           = 'Nivel superior para la tabla de contenidos';
$lang['tocminheads']           = 'La cantidad mínima de titulares que determina si el TOC es construido';
$lang['maxtoclevel']           = 'Máximo nivel para la tabla de contenidos';
$lang['maxseclevel']           = 'Máximo nivel para edición de sección';
$lang['camelcase']             = 'Usar CamelCase para enlaces';
$lang['deaccent']              = 'Nombres de páginas "limpios"';
$lang['useheading']            = 'Usar el primer encabezado para nombres de páginas';
$lang['refcheck']              = 'Control de referencia a medios';
$lang['refshow']               = 'Número de referencias a medios a mostrar';
$lang['allowdebug']            = 'Permitir debug <b>deshabilítelo si no lo necesita!</b>';
$lang['usewordblock']          = 'Bloquear spam usando una lista de palabras';
$lang['indexdelay']            = 'Intervalo de tiempo antes de indexar (segundos)';
$lang['relnofollow']           = 'Usar rel="nofollow" en enlaces externos';
$lang['mailguard']             = 'Ofuscar direcciones de correo electrónico';
$lang['iexssprotect']          = 'Comprobar posible código malicioso (JavaScript ó HTML) en archivos subidos';
$lang['showuseras']            = 'Qué ver al mostrar el último usuario que editó una página';
$lang['useacl']                = 'Usar listas de control de acceso (ACL)';
$lang['autopasswd']            = 'Autogenerar contraseñas';
$lang['authtype']              = 'Método de Autenticación';
$lang['passcrypt']             = 'Método de cifrado de contraseñas';
$lang['defaultgroup']          = 'Grupo por defecto';
$lang['superuser']             = 'Super-usuario - grupo ó usuario con acceso total a todas las páginas y funciones, configuraciones ACL';
$lang['manager']               = 'Manager - grupo ó usuario con acceso a ciertas tareas de mantenimiento.';
$lang['profileconfirm']        = 'Confirmar cambios en perfil con contraseña';
$lang['disableactions']        = 'Deshabilitar acciones DokuWiki';
$lang['disableactions_check']  = 'Controlar';
$lang['disableactions_subscription'] = 'Subscribirse/Desubscribirse';
$lang['disableactions_nssubscription'] = 'Directorio Subscribirse/Desubscribirse';
$lang['disableactions_wikicode'] = 'Ver el fuente/Exportar en formato crudo (raw)';
$lang['disableactions_other']  = 'Otras acciones (separadas por coma)';
$lang['sneaky_index']          = 'Por defecto, DokuWiki mostrará todos los namespaces en el index. Habilitando esta opción los ocultará si el usuario no tiene permisos de lectura. Los sub-namespaces pueden resultar inaccesibles. El index puede hacerse poco usable dependiendo de las configuraciones ACL.';
$lang['auth_security_timeout'] = 'Tiempo de Autenticación (en segundos), por motivos de seguridad';
$lang['securecookie']          = 'Las cookies establecidas por HTTPS, el naveagdor solo puede enviarlas por HTTPS?
Inhabilite esta opción cuando solo se asegure la entrada , pero no la navegación de su wiki.';
$lang['updatecheck']           = 'Comprobar actualizaciones y advertencias de seguridad? Esta característica requiere que Dokuwiki se conecte a splitbrain.org.';
$lang['userewrite']            = 'Usar URLs bonitas';
$lang['useslash']              = 'Usar barra (/) como separador de espacios de nombres en las URLs';
$lang['usedraft']              = 'Guardar automáticamente un borrador mientras se edita';
$lang['sepchar']               = 'Separador de palabras en nombres de páginas';
$lang['canonical']             = 'Usar URLs totalmente canónicas';
$lang['autoplural']            = 'Controlar plurales en enlaces';
$lang['compression']           = 'Método de compresión para archivos en el ático';
$lang['cachetime']             = 'Edad máxima para caché (segundos)';
$lang['locktime']              = 'Edad máxima para archivos de lock (segundos)';
$lang['fetchsize']             = 'Tamaño máximo (bytes) que fetch.php puede descargar de sitios externos';
$lang['notify']                = 'Enviar notificación de cambios a esta dirección de correo electrónico';
$lang['registernotify']        = 'Enviar información cuando se registran nuevos usuarios a esta dirección de correo electrónico';
$lang['mailfrom']              = 'Dirección de correo electrónico para emails automáticos';
$lang['gzip_output']           = 'Usar gzip Content-Encoding para xhtml';
$lang['gdlib']                 = 'Versión de GD Lib';
$lang['im_convert']            = 'Ruta a la herramienta de conversión de ImageMagick';
$lang['jpg_quality']           = 'Calidad de compresión de JPG (0-100)';
$lang['subscribers']           = 'Habilitar soporte para suscripción a páginas';
$lang['compress']              = 'Compactar la salida de CSS y javascript';
$lang['hidepages']             = 'Ocultar páginas con coincidencias (expresiones regulares)';
$lang['send404']               = 'Enviar "HTTP 404/Page Not Found" para páginas no existentes';
$lang['sitemap']               = 'Generar sitemap de Google (días)';
$lang['broken_iua']            = '¿Se ha roto su sistema a causa de la función ignore_user_abort?. Esto puede causar que no funcione el index de búsqueda. Leer el <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>para más información.';
$lang['xsendfile']             = 'Utilice el X-Sendfile header para permitirle sl servidor web enviar archivos estáticos? Su servidor web necesita tener la capacidad para hacerlo.';
$lang['xmlrpc']                = 'Habilitar/Deshabilitar interfase XML-RPC';
$lang['renderer_xhtml']        = 'Visualizador a usar para salida (xhtml) principal del wiki';
$lang['renderer__core']        = '%s (nucleo dokuwiki)';
$lang['renderer__plugin']      = '%s (complemento)';
$lang['rememberme']            = 'Permitir cookies para acceso permanente (recordarme)';
$lang['rss_type']              = 'Tipo de resumen (feed) XML';
$lang['rss_linkto']            = 'Feed XML enlaza a';
$lang['rss_content']           = 'Que mostrar en los itemes del archivo XML?';
$lang['rss_update']            = 'Intervalo de actualización de feed XML (segundos)';
$lang['recent_days']           = 'Cuántos cambios recientes mantener (días)';
$lang['rss_show_summary']      = 'Feed XML muestra el resumen en el título';
$lang['target____wiki']        = 'Ventana para enlaces internos';
$lang['target____interwiki']   = 'Ventana para enlaces interwikis';
$lang['target____extern']      = 'Ventana para enlaces externos';
$lang['target____media']       = 'Ventana para enlaces a medios';
$lang['target____windows']     = 'Ventana para enlaces a ventanas';
$lang['proxy____host']         = 'Nombre del servidor Proxy';
$lang['proxy____port']         = 'Puerto del servidor Proxy';
$lang['proxy____user']         = 'Nombre de usuario para el servidor Proxy';
$lang['proxy____pass']         = 'Contraseña para el servidor Proxy';
$lang['proxy____ssl']          = 'Usar ssl para conectarse al servidor Proxy';
$lang['safemodehack']          = 'Habilitar edición (hack) de modo seguro';
$lang['ftp____host']           = 'Nombre del servidor FTP  para modo seguro';
$lang['ftp____port']           = 'Puerto del servidor FTP  para modo seguro';
$lang['ftp____user']           = 'Nombre de usuario para el servidor FTP  para modo seguro';
$lang['ftp____pass']           = 'Contraseña para el servidor FTP  para modo seguro';
$lang['ftp____root']           = 'Directorio raiz para el servidor FTP  para modo seguro';
$lang['license_o_']            = 'No se eligió ninguna';
$lang['typography_o_0']        = 'ninguno';
$lang['typography_o_1']        = 'Dobles comillas solamente';
$lang['typography_o_2']        = 'Todas las comillas (puede ser que no siempre funcione)';
$lang['userewrite_o_0']        = 'ninguno';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'Interno de DokuWiki';
$lang['deaccent_o_0']          = 'Apagado';
$lang['deaccent_o_1']          = 'Eliminar tildes';
$lang['deaccent_o_2']          = 'Romanizar';
$lang['gdlib_o_0']             = 'GD Lib no está disponible';
$lang['gdlib_o_1']             = 'Versión 1.x';
$lang['gdlib_o_2']             = 'Autodetección';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Resumen';
$lang['rss_content_o_diff']    = 'Diferencias unificadas';
$lang['rss_content_o_htmldiff'] = 'Tabla de diferencias en formato HTML';
$lang['rss_content_o_html']    = 'Página que solo contiene código HTML';
$lang['rss_linkto_o_diff']     = 'ver las diferencias';
$lang['rss_linkto_o_page']     = 'la página revisada';
$lang['rss_linkto_o_rev']      = 'lista de revisiones';
$lang['rss_linkto_o_current']  = 'la página actual';
$lang['compression_o_0']       = 'Ninguna';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'No utiliazar';
$lang['xsendfile_o_1']         = 'Encabezado propietario de lighttpd (antes de la versión 1.5)';
$lang['xsendfile_o_2']         = 'Encabezado X-Sendfile estándar';
$lang['xsendfile_o_3']         = 'Encabezado propietario Nginx X-Accel-Redirect';
$lang['showuseras_o_loginname'] = 'Nombre de entrada';
$lang['showuseras_o_username'] = 'Nombre completo del usuario';
$lang['showuseras_o_email']    = 'Dirección de correo electrónico del usuario (Ofuscada según la configuración de "mailguard")';
$lang['showuseras_o_email_link'] = 'Dirección de correo de usuario como enlace de envío de correo';
$lang['useheading_o_0']        = 'Nunca';
$lang['useheading_o_navigation'] = 'Solamente Navegacion';
$lang['useheading_o_content']  = 'Contenido Wiki solamente';
$lang['useheading_o_1']        = 'Siempre';
